summaryrefslogtreecommitdiffstats
path: root/kio/kfile
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
commitd4e11a5f488204ab8886e167c7c4af1e6e16ab58 (patch)
tree367a2caa6169a869cfbf6395dffe2d28e0f72654 /kio/kfile
parent2c4de80e1e29b261fe8770483f97b2d702e4bd08 (diff)
downloadtdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.tar.gz
tdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.zip
Use non-tq sizeHint functions to fix bindings
Diffstat (limited to 'kio/kfile')
-rw-r--r--kio/kfile/kfiledialog.cpp2
-rw-r--r--kio/kfile/kfilemetapreview.cpp2
-rw-r--r--kio/kfile/kfilepreview.cpp6
-rw-r--r--kio/kfile/kfilespeedbar.cpp10
-rw-r--r--kio/kfile/kfilespeedbar.h2
-rw-r--r--kio/kfile/kicondialog.cpp2
-rw-r--r--kio/kfile/kimagefilepreview.cpp2
-rw-r--r--kio/kfile/kimagefilepreview.h2
-rw-r--r--kio/kfile/kmetaprops.cpp4
-rw-r--r--kio/kfile/knotifywidgetbase.ui8
-rw-r--r--kio/kfile/kopenwith.cpp4
-rw-r--r--kio/kfile/kpropertiesdesktopadvbase.ui6
-rw-r--r--kio/kfile/kpropertiesdesktopbase.ui6
-rw-r--r--kio/kfile/kpropertiesdialog.cpp14
-rw-r--r--kio/kfile/kurlbar.cpp28
-rw-r--r--kio/kfile/kurlbar.h6
-rw-r--r--kio/kfile/kurlrequesterdlg.cpp2
17 files changed, 53 insertions, 53 deletions
diff --git a/kio/kfile/kfiledialog.cpp b/kio/kfile/kfiledialog.cpp
index a1668693d..fbc6dd7ab 100644
--- a/kio/kfile/kfiledialog.cpp
+++ b/kio/kfile/kfiledialog.cpp
@@ -1738,7 +1738,7 @@ void KFileDialog::readConfig( KConfig *kc, const TQString& group )
updateAutoSelectExtension ();
int w1 = tqminimumSize().width();
- int w2 = toolbar->tqsizeHint().width() + 10;
+ int w2 = toolbar->sizeHint().width() + 10;
if (w1 < w2)
setMinimumWidth(w2);
diff --git a/kio/kfile/kfilemetapreview.cpp b/kio/kfile/kfilemetapreview.cpp
index 3c73387b4..c8b89b5d6 100644
--- a/kio/kfile/kfilemetapreview.cpp
+++ b/kio/kfile/kfilemetapreview.cpp
@@ -43,7 +43,7 @@ void KFileMetaPreview::initPreviewProviders()
KImageFilePreview *imagePreview = new KImageFilePreview( m_stack );
(void) m_stack->addWidget( imagePreview );
m_stack->raiseWidget( imagePreview );
- resize( imagePreview->tqsizeHint() );
+ resize( imagePreview->sizeHint() );
TQStringList mimeTypes = imagePreview->supportedMimeTypes();
TQStringList::ConstIterator it = mimeTypes.begin();
diff --git a/kio/kfile/kfilepreview.cpp b/kio/kfile/kfilepreview.cpp
index 8ce3e87af..877260a5f 100644
--- a/kio/kfile/kfilepreview.cpp
+++ b/kio/kfile/kfilepreview.cpp
@@ -68,9 +68,9 @@ void KFilePreview::init( KFileView *view )
preview = new TQWidget((TQSplitter*)this, "preview");
TQString tmp = i18n("No preview available.");
TQLabel *l = new TQLabel(tmp, preview);
- l->setMinimumSize(l->tqsizeHint());
+ l->setMinimumSize(l->sizeHint());
l->move(10, 5);
- preview->setMinimumWidth(l->tqsizeHint().width()+20);
+ preview->setMinimumWidth(l->sizeHint().width()+20);
setResizeMode(preview, TQSplitter::KeepSize);
// Why copy the actions? --ellis, 13 Jan 02.
@@ -123,7 +123,7 @@ void KFilePreview::setPreviewWidget(const TQWidget *w, const KURL &)
delete preview;
preview = const_cast<TQWidget*>(w);
preview->reparent((TQSplitter*)this, 0, TQPoint(0, 0), true);
- preview->resize(preview->tqsizeHint());
+ preview->resize(preview->sizeHint());
preview->show();
}
diff --git a/kio/kfile/kfilespeedbar.cpp b/kio/kfile/kfilespeedbar.cpp
index c3449ca9b..154009625 100644
--- a/kio/kfile/kfilespeedbar.cpp
+++ b/kio/kfile/kfilespeedbar.cpp
@@ -133,15 +133,15 @@ void KFileSpeedBar::save( KConfig *config )
writeConfig( config, "KFileDialog Speedbar" );
}
-TQSize KFileSpeedBar::tqsizeHint() const
+TQSize KFileSpeedBar::sizeHint() const
{
- TQSize tqsizeHint = KURLBar::tqsizeHint();
+ TQSize sizeHint = KURLBar::sizeHint();
int ems = fontMetrics().width("mmmmmmmmmmmm");
- if (tqsizeHint.width() < ems)
+ if (sizeHint.width() < ems)
{
- tqsizeHint.setWidth(ems);
+ sizeHint.setWidth(ems);
}
- return tqsizeHint;
+ return sizeHint;
}
#include "kfilespeedbar.moc"
diff --git a/kio/kfile/kfilespeedbar.h b/kio/kfile/kfilespeedbar.h
index 171081101..28c621651 100644
--- a/kio/kfile/kfilespeedbar.h
+++ b/kio/kfile/kfilespeedbar.h
@@ -31,7 +31,7 @@ public:
~KFileSpeedBar();
virtual void save( KConfig *config );
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
private:
bool m_initializeSpeedbar : 1;
diff --git a/kio/kfile/kicondialog.cpp b/kio/kfile/kicondialog.cpp
index e600f2679..150536a33 100644
--- a/kio/kfile/kicondialog.cpp
+++ b/kio/kfile/kicondialog.cpp
@@ -367,7 +367,7 @@ void KIconDialog::init()
mContextMap[ mNumContext++ ] = context_id[ i ];
}
}
- mpCombo->setFixedSize(mpCombo->tqsizeHint());
+ mpCombo->setFixedSize(mpCombo->sizeHint());
mpBrowseBut->setFixedWidth(mpCombo->width());
diff --git a/kio/kfile/kimagefilepreview.cpp b/kio/kfile/kimagefilepreview.cpp
index f2869314c..16cef138d 100644
--- a/kio/kfile/kimagefilepreview.cpp
+++ b/kio/kfile/kimagefilepreview.cpp
@@ -137,7 +137,7 @@ void KImageFilePreview::resizeEvent( TQResizeEvent * )
timer->start( 100, true ); // forces a new preview
}
-TQSize KImageFilePreview::tqsizeHint() const
+TQSize KImageFilePreview::sizeHint() const
{
return TQSize( 20, 200 ); // otherwise it ends up huge???
}
diff --git a/kio/kfile/kimagefilepreview.h b/kio/kfile/kimagefilepreview.h
index 3e64f2a7b..864fc5d31 100644
--- a/kio/kfile/kimagefilepreview.h
+++ b/kio/kfile/kimagefilepreview.h
@@ -36,7 +36,7 @@ class KIO_EXPORT KImageFilePreview : public KPreviewWidgetBase
KImageFilePreview(TQWidget *parent);
~KImageFilePreview();
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
public slots:
virtual void showPreview(const KURL &url);
diff --git a/kio/kfile/kmetaprops.cpp b/kio/kfile/kmetaprops.cpp
index 38906bbd3..1b85cbab0 100644
--- a/kio/kfile/kmetaprops.cpp
+++ b/kio/kfile/kmetaprops.cpp
@@ -56,8 +56,8 @@ protected:
virtual void viewportResizeEvent(TQResizeEvent* ev)
{
TQScrollView::viewportResizeEvent(ev);
- m_frame->resize( kMax(m_frame->tqsizeHint().width(), ev->size().width()),
- kMax(m_frame->tqsizeHint().height(), ev->size().height()));
+ m_frame->resize( kMax(m_frame->sizeHint().width(), ev->size().width()),
+ kMax(m_frame->sizeHint().height(), ev->size().height()));
};
private:
diff --git a/kio/kfile/knotifywidgetbase.ui b/kio/kfile/knotifywidgetbase.ui
index c2ce7ab68..d3c3103ff 100644
--- a/kio/kfile/knotifywidgetbase.ui
+++ b/kio/kfile/knotifywidgetbase.ui
@@ -138,7 +138,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>20</height>
@@ -155,7 +155,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>318</width>
<height>16</height>
@@ -286,7 +286,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>20</height>
@@ -391,7 +391,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>0</height>
diff --git a/kio/kfile/kopenwith.cpp b/kio/kfile/kopenwith.cpp
index e5754cefb..0b32bc684 100644
--- a/kio/kfile/kopenwith.cpp
+++ b/kio/kfile/kopenwith.cpp
@@ -401,7 +401,7 @@ void KOpenWithDlg::init( const TQString& _text, const TQString& _value )
TQToolButton *clearButton = new TQToolButton( this );
clearButton->setIconSet( BarIcon( "locationbar_erase" ) );
- clearButton->setFixedSize( clearButton->tqsizeHint() );
+ clearButton->setFixedSize( clearButton->sizeHint() );
connect( clearButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotClear() ) );
TQToolTip::add( clearButton, i18n( "Clear input field" ) );
@@ -518,7 +518,7 @@ void KOpenWithDlg::init( const TQString& _text, const TQString& _value )
//edit->setText( _value );
// This is what caused "can't click on items before clicking on Name header".
// Probably due to the resizeEvent handler using width().
- //resize( minimumWidth(), tqsizeHint().height() );
+ //resize( minimumWidth(), sizeHint().height() );
edit->setFocus();
slotTextChanged();
}
diff --git a/kio/kfile/kpropertiesdesktopadvbase.ui b/kio/kfile/kpropertiesdesktopadvbase.ui
index a4ac75d4f..fd8e39781 100644
--- a/kio/kfile/kpropertiesdesktopadvbase.ui
+++ b/kio/kfile/kpropertiesdesktopadvbase.ui
@@ -41,7 +41,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -120,7 +120,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -230,7 +230,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>50</width>
<height>20</height>
diff --git a/kio/kfile/kpropertiesdesktopbase.ui b/kio/kfile/kpropertiesdesktopbase.ui
index 73e6d953c..a0894dc70 100644
--- a/kio/kfile/kpropertiesdesktopbase.ui
+++ b/kio/kfile/kpropertiesdesktopbase.ui
@@ -29,7 +29,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -259,7 +259,7 @@ Following the command, you can have several place holders which will be replaced
<property name="sizeType">
<enum>MinimumExpanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>53</width>
<height>20</height>
@@ -287,7 +287,7 @@ Following the command, you can have several place holders which will be replaced
<property name="sizeType">
<enum>MinimumExpanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>53</width>
<height>20</height>
diff --git a/kio/kfile/kpropertiesdialog.cpp b/kio/kfile/kpropertiesdialog.cpp
index a3c1739ad..6496b2cdb 100644
--- a/kio/kfile/kpropertiesdialog.cpp
+++ b/kio/kfile/kpropertiesdialog.cpp
@@ -1966,7 +1966,7 @@ void KFilePermissionsPropsPlugin::slotShowAdvancedPermissions() {
TQWhatsThis::add(l, execWhatsThis);
theNotSpecials.append( l );
// GJ: Add space between normal and special modes
- TQSize size = l->tqsizeHint();
+ TQSize size = l->sizeHint();
size.setWidth(size.width() + 15);
l->setFixedSize(size);
gl->addWidget (l, 1, 3);
@@ -2685,35 +2685,35 @@ KBindingPropsPlugin::KBindingPropsPlugin( KPropertiesDialog *_props ) : KPropsDl
tmpQLabel = new TQLabel( d->m_frame, "Label_1" );
tmpQLabel->setText( i18n("Pattern ( example: *.html;*.htm )") );
- tmpQLabel->setMinimumSize(tmpQLabel->tqsizeHint());
+ tmpQLabel->setMinimumSize(tmpQLabel->sizeHint());
mainlayout->addWidget(tmpQLabel, 1);
//patternEdit->setGeometry( 10, 40, 210, 30 );
//patternEdit->setText( "" );
patternEdit->setMaxLength( 512 );
- patternEdit->setMinimumSize( patternEdit->tqsizeHint() );
+ patternEdit->setMinimumSize( patternEdit->sizeHint() );
patternEdit->setFixedHeight( fontHeight );
mainlayout->addWidget(patternEdit, 1);
tmpQLabel = new TQLabel( d->m_frame, "Label_2" );
tmpQLabel->setText( i18n("Mime Type") );
- tmpQLabel->setMinimumSize(tmpQLabel->tqsizeHint());
+ tmpQLabel->setMinimumSize(tmpQLabel->sizeHint());
mainlayout->addWidget(tmpQLabel, 1);
//mimeEdit->setGeometry( 10, 160, 210, 30 );
mimeEdit->setMaxLength( 256 );
- mimeEdit->setMinimumSize( mimeEdit->tqsizeHint() );
+ mimeEdit->setMinimumSize( mimeEdit->sizeHint() );
mimeEdit->setFixedHeight( fontHeight );
mainlayout->addWidget(mimeEdit, 1);
tmpQLabel = new TQLabel( d->m_frame, "Label_3" );
tmpQLabel->setText( i18n("Comment") );
- tmpQLabel->setMinimumSize(tmpQLabel->tqsizeHint());
+ tmpQLabel->setMinimumSize(tmpQLabel->sizeHint());
mainlayout->addWidget(tmpQLabel, 1);
//commentEdit->setGeometry( 10, 100, 210, 30 );
commentEdit->setMaxLength( 256 );
- commentEdit->setMinimumSize( commentEdit->tqsizeHint() );
+ commentEdit->setMinimumSize( commentEdit->sizeHint() );
commentEdit->setFixedHeight( fontHeight );
mainlayout->addWidget(commentEdit, 1);
diff --git a/kio/kfile/kurlbar.h b/kio/kfile/kurlbar.h
index 32969cff7..29a73ff34 100644
--- a/kio/kfile/kurlbar.h
+++ b/kio/kfile/kurlbar.h
@@ -109,7 +109,7 @@ public:
* returns the preferred size of this item
* @since 3.1
*/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
/**
* returns the width of this item.
@@ -319,12 +319,12 @@ public:
* @returns a proper sizehint, depending on the orientation and the number
* of items available.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* @returns a proper minimum size (reimplemented)
*/
- virtual TQSize tqminimumSizeHint() const;
+ virtual TQSize minimumSizeHint() const;
/**
* Call this method to read a saved configuration from @p config,
diff --git a/kio/kfile/kurlrequesterdlg.cpp b/kio/kfile/kurlrequesterdlg.cpp
index defa09264..19409afdc 100644
--- a/kio/kfile/kurlrequesterdlg.cpp
+++ b/kio/kfile/kurlrequesterdlg.cpp
@@ -67,7 +67,7 @@ void KURLRequesterDlg::initDialog(const TQString &text,const TQString &urlName)
topLayout->addWidget( label );
urlRequester_ = new KURLRequester( urlName, plainPage(), "urlRequester" );
- urlRequester_->setMinimumWidth( urlRequester_->tqsizeHint().width() * 3 );
+ urlRequester_->setMinimumWidth( urlRequester_->sizeHint().width() * 3 );
topLayout->addWidget( urlRequester_ );
urlRequester_->setFocus();
connect( urlRequester_->lineEdit(), TQT_SIGNAL(textChanged(const TQString&)),
diff --git a/kio/kfile/kurlbar.cpp b/kio/kfile/kurlbar.cpp
index 218a72f37..ca5359f38 100644
--- a/kio/kfile/kurlbar.cpp
+++ b/kio/kfile/kurlbar.cpp
@@ -268,7 +268,7 @@ void KURLBarItem::paint( TQPainter *p )
}
}
-TQSize KURLBarItem::tqsizeHint() const
+TQSize KURLBarItem::sizeHint() const
{
int wmin = 0;
int hmin = 0;
@@ -284,9 +284,9 @@ TQSize KURLBarItem::tqsizeHint() const
}
if ( lb->isVertical() )
- wmin = QMIN( wmin, lb->viewport()->tqsizeHint().width() );
+ wmin = QMIN( wmin, lb->viewport()->sizeHint().width() );
else
- hmin = QMIN( hmin, lb->viewport()->tqsizeHint().height() );
+ hmin = QMIN( hmin, lb->viewport()->sizeHint().height() );
return TQSize( wmin, hmin );
}
@@ -294,17 +294,17 @@ TQSize KURLBarItem::tqsizeHint() const
int KURLBarItem::width( const TQListBox *lb ) const
{
if ( static_cast<const KURLBarListBox *>( lb )->isVertical() )
- return QMAX( tqsizeHint().width(), lb->viewport()->width() );
+ return QMAX( sizeHint().width(), lb->viewport()->width() );
else
- return tqsizeHint().width();
+ return sizeHint().width();
}
int KURLBarItem::height( const TQListBox *lb ) const
{
if ( static_cast<const KURLBarListBox *>( lb )->isVertical() )
- return tqsizeHint().height();
+ return sizeHint().height();
else
- return QMAX( tqsizeHint().height(), lb->viewport()->height() );
+ return QMAX( sizeHint().height(), lb->viewport()->height() );
}
bool KURLBarItem::isPersistent() const
@@ -435,7 +435,7 @@ void KURLBar::setIconSize( int size )
item = static_cast<KURLBarItem*>( item->next() );
}
- resize( tqsizeHint() );
+ resize( sizeHint() );
updateGeometry();
}
@@ -466,14 +466,14 @@ void KURLBar::paletteChange( const TQPalette & )
setPalette( pal );
}
-TQSize KURLBar::tqsizeHint() const
+TQSize KURLBar::sizeHint() const
{
- return m_listBox->tqsizeHint();
+ return m_listBox->sizeHint();
#if 0
// this code causes vertical and or horizontal scrollbars appearing
// depending on the text, font, moonphase and earth rotation. Just using
// m_listBox->tqsizeHint() fixes this (although the widget can then be
// resized to a smaller size so that scrollbars appear).
int w = 0;
int h = 0;
@@ -484,7 +484,7 @@ TQSize KURLBar::tqsizeHint() const
item;
item = static_cast<KURLBarItem*>( item->next() ) ) {
- TQSize sh = item->tqsizeHint();
+ TQSize sh = item->sizeHint();
if ( vertical ) {
w = QMAX( w, sh.width() );
@@ -508,9 +508,9 @@ TQSize KURLBar::tqsizeHint() const
#endif
}
-TQSize KURLBar::tqminimumSizeHint() const
+TQSize KURLBar::minimumSizeHint() const
{
- TQSize s = tqsizeHint(); // ###
+ TQSize s = sizeHint(); // ###
int w = s.width() + m_listBox->verticalScrollBar()->width();
int h = s.height() + m_listBox->horizontalScrollBar()->height();
return TQSize( w, h );
@@ -466,14 +466,14 @@ void KURLBar::paletteChange( const TQPalette & )
// this code causes vertical and or horizontal scrollbars appearing
// depending on the text, font, moonphase and earth rotation. Just using
- // m_listBox->tqsizeHint() fixes this (although the widget can then be
+ // m_listBox->sizeHint() fixes this (although the widget can then be
// resized to a smaller size so that scrollbars appear).
int w = 0;